@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: resourcet
-version: 1.1.7.2
-id: resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
-key: resou_HWB49L1IJrPDhLpyOF3QKr
+version: 1.1.7.3
+id: resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+key: resou_FD3YBQAG5YCJcmLlgosnnd
 license: BSD3
 maintainer: michael@snoyman.com
 homepage: http://github.com/snoyberg/conduit
@@ -17,10 +17,10 @@ exposed-modules:
     Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
     Data.Acquire Data.Acquire.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/resourcet-1.1.7.2
-hs-libraries: HSresourcet-1.1.7.2-HWB49L1IJrPDhLpyOF3QKr
+import-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/resourcet-1.1.7.3
+hs-libraries: HSresourcet-1.1.7.3-FD3YBQAG5YCJcmLlgosnnd
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
